@@ -129,6 +129,9 @@ class ContextValue(Lazy):
             return resolve_lookup(context, self.value)
         return self.value
 
+    def __str__(self):
+        return f"{self.__class__.__name__}(value='{self.value}')"
+
 
 class ContextFunction(Lazy):
     """Call a function a render time, usefull for calculation of more complex"""
@@ -140,6 +143,9 @@ class ContextFunction(Lazy):
     def resolve(self, context: dict) -> typing.Any:
         return self.func(context)
 
+    def __str__(self):
+        return f"{self.__class__.__name__}(func='{self.func}')"
+
 
 C = ContextValue
 F = ContextFunction
